########################################################################
#                                                                      #
#  Sample Control File for AF4Max                                      #
#                                                                      #
#  This file can be used to demonstrate the use of an external         #
#  control file with AF4Max.  Actions and options are entered the      #
#  same way they would be entered on the commmand line.  Blank lines   #
#  or lines beginning with an octothorpe (#) are ignored.  Multiple    #
#  options may be entered on a line provided they are separated by     #
#  one or more spaces or tabs.  Anything following an octothorpe on    #
#  a line will be treated as a comment.                                #
#                                                                      #
#  See the README file for complete information regarding the          #
#  available action and option parameters.                             #
#                                                                      #
########################################################################

##############################
#       A C T I O N S        #
##############################

--allfiles=AllFiles.txt
   #   Instructs the program to produce a listing of all file areas,
   #   and to store the output in a file called "filename".  If there
   #   is no filename provided, the information will be output to a
   #   file called AllFiles.txt in the current directory.

--newfiles=NewFiles.txt
   #   Instructs the program to produce a listing of all file areas
   #   showing only new files, and to store the output in a file called
   #   "filename".  If there is no filename provided, the information
   #   will be output to a file called NewFiles.txt in the current
   #   directory.

--htmlallfiles=AllFiles.html
   #   Instructs the program to produce a listing of all file areas, and
   #   to store the output in a format suitable for use by a web server.
   #   In addition to "index.html" files in each file directory, a
   #   master list of the file areas will be saved to "filename". If
   #   there is no filename provided, the information will be output to
   #   a file called AllFiles.html in the current directory.

--htmlnewfiles=NewFiles.html
   #   Instructs the program to produce a listing of all new files, and
   #   to store the output in a format suitable for use by a web server.
   #   If there is no filename provided, the information will be output
   #   to a file called NewFiles.html in the current directory.


##############################
#       O P T I O N S        #
##############################

#--control=af4max.ctl
   #   Instructs the program to read action and option parameters from a
   #   file called "filename". Parameters read from this file will be
   #   processed as if they were entered on the command line.  Blank
   #   lines and lines beginning with an octothorpe (#) will be ignored.
   #   Multiple options may be entered on a line provided they are
   #   separated by one or more spaces or tabs.

--quiet
   #   Supresses screen output during processing.  This option is most
   #   often used when the program is called as a cron job.

--showhidden
   #   Causes the resulting program output to include those file areas
   #   marked as type "hidden".

--logfile=af4max.log
   #   Causes progress information to be saved in a log file called
   #   "filename".  If there is no filename provided, then the
   #   information will be stored in a file called af4max.log in the
   #   current directory.

--loglevel=5			#override default
   #   Sets the trigger level for logging information to "number". The
   #   level can be any number between 1 (critical errors only) and 5
   #   (debug -- log everything).  The default logging level is 3.

--sysop="Bob Swift"
   #   Overrides the system operator's name as found in the max.ctl file.
   #   If the name contains spaces, it can either be entered within
   #   quotes ("SysOp Name") or by replacing the spaces with underscores
   #   (SysOp_Name).  All underscores will be replaced with spaces before
   #   the name is written to any files.

--email=powerstation@shaw.ca
   #   Allows setting the system operator's internet email address.  If
   #   this is set, then there will be a "mailto:" link included on each
   #   of the HTML pages generated.  This email address will be masked
   #   using JavaScript to prevent it from being harvested by spambots.

--newdays=3			#override default
   #   Sets the number of days to show in the new files list to "number"
   #   rather than the default of 7 days.

--head=af4max.hdr
   #   Instructs the program to use the file "filename" for the header
   #   for AllFiles.txt rather than the default header file af4max.hdr.
   #   If the header file cannot be read, then the script will build a
   #   default header based on the information read from the max.ctl
   #   file.

--htmlhead=af4max-h.hdr
   #   Instructs the program to use the file "filename" for the header
   #   for the html pages.  If this file is not specified or cannot be
   #   read, then the script will build a default header based on the
   #   information read from the max.ctl file.  The contents of this
   #   file are inserted immediately following the opening <BODY> tag.

--htmlfoot=af4max-h.ftr
   #   Instructs the program to use the file "filename" for the footer
   #   for the html pages.  If this file is not specified or cannot be
   #   read, then the script will build a default footer based on the
   #   information read from the max.ctl file.  The contents of this
   #   file are inserted immediately before the closing </BODY> tag.

--htmlincl=af4max-h.inc
   #   Instructs the program to insert the contents of the file
   #   "filename" into the <HEAD>...</HEAD> section of the html pages.

--map=c:\max\fileroot\*/pub/	#map c:\max\fileroot\ to /pub/
   #   Instructs the program to replace all occurrences of "from" with
   #   "to" at the start of paths used for links within the html files.
   #   This option may be used more than once to create multiple mapping
   #   criteria.  Note that "from" and "to" are separated by an asterisk
   #   (*) with no spaces.

#--path=/max/
   #   Instructs the program to look for the max.ctl and filearea.ctl
   #   control files in "filepath" rather than in the current directory.

#--max=max.ctl
   #   Instructs the program to use the file "filename" rather than
   #   max.ctl for the Maximus system configuration information.

#--filearea=filearea.ctl
   #   Instructs the program to use the file "filename" rather than
   #   filearea.ctl for the Maximus file area configuration information.

########################################################################
